
#Load required packages
library(nlme)
library(segmented)
library(performance)

#Read in and check the data
d<-read.csv("Caspian.Bewick.Data.csv")
str(d)

#Fit linear temporal model
model1<-gls(Count~Year, data=d)

#Examine model residuals for temporal autocorrelation
plot(ACF(model1,resType="normalized"),alpha=0.05)

#Fit models that vary in number of breakpoints in the Year variable
null.model.0<-lm(Count~1, data=d)
linear.model.0<-lm(Count~Year, data=d)
segmented.model.1<-segmented(linear.model.0, seg.Z = ~Year, psi=c(2009))
segmented.model.2<-segmented(linear.model.0, seg.Z = ~Year, psi=c(2005,2015))

#A model with three breakpoints cannot be estimated from the data
segmented.model.3<-segmented(linear.model.0, seg.Z = ~Year, psi=c(2005,2012,2020))

#Compare performance of each of the models
summary(null.model.0)
summary(linear.model.0)
summary(segmented.model.1)
summary(segmented.model.2)

AIC(null.model.0)
AIC(linear.model.0)
AIC(segmented.model.1)
AIC(segmented.model.2)

#Check model residuals meet assumptions
check_model(linear.model.0)
check_model(segmented.model.2)

#Visualise best model estimate
plot(d$Year, d$Count, pch=16, col='steelblue')
plot(segmented.model.2, add=T)
